@@ -2,24 +2,10 @@ use strict;
 use warnings;
 
 package NanoMsg::Raw::Message;
-our $AUTHORITY = 'cpan:FLORA';
 # ABSTRACT: Message buffer for NanoMsg::Raw
-$NanoMsg::Raw::Message::VERSION = '0.06';
+
 use overload '""' => sub { ${ $_[0] } }, fallback => 1;
 
-
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-NanoMsg::Raw::Message - Message buffer for NanoMsg::Raw
-
 =head1 SYNOPSIS
 
     use NanoMsg::Raw;
@@ -51,9 +37,7 @@ containing a copy of the buffer content.
 A string pointing to the actual buffer content, without having to create a copy
 of it, can be obtained by dereferencing the message instance as a scalar.
 
-=head1 METHODS
-
-=head2 copy($data)
+=method copy($data)
 
     $msg->copy('foo');
 
@@ -64,26 +48,6 @@ space allocated for the buffer, an exception will be thrown.
 
 L<NanoMsg::Raw>
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
-Boris Zentner <bzm@2bz.de>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2015 by Florian Ragwitz.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
 =cut
+
+1;
